package com.emdoor.scannerdemo;

import androidx.appcompat.app.AppCompatActivity;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Build;
import android.os.Bundle;
import android.view.View;
import android.widget.TextView;
import android.widget.ToggleButton;

import com.emdoor.scannerdemo.utils.SharedPreferencesUtil;
import com.zebra.BarcodeScanner;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;

public class MainActivity extends AppCompatActivity {
    private ToggleButton mSwitch;
    private TextView mShow;

    private BroadcastReceiver receiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            if (BarcodeScanner.BARCODEPORT_RECEIVEDDATA_ACTION.equals(action)) {
                // 接收扫码数据
                String data = intent.getStringExtra(BarcodeScanner.BARCODEPORT_RECEIVEDDATA_EXTRA_DATA);
                CharSequence text = mShow.getText();
                if (text == null || text.toString().isEmpty()) {
                    mShow.setText(data + "\r\n");
                } else {
                    mShow.append(data + "\r\n");
                }
            }
        }
    };

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        mSwitch = findViewById(R.id.tb_switch_mode);
        mShow = findViewById(R.id.tv_show);

        mSwitch.setChecked(SharedPreferencesUtil.getBoolean("widgetMode", false));

        mSwitch.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                SharedPreferencesUtil.put("widgetMode", mSwitch.isChecked());
            }
        });

        startScannerService();
    }

    @Override
    protected void onResume() {
        super.onResume();
        String model = SharedPreferencesUtil.getString("model", "");
        if (model.contains("Q") || model.contains("q")) {
            keySwitchToTiggerQcom("3"); //高通平台需要写入节点上电
        }
        startScannerService();
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction(BarcodeScanner.BARCODEPORT_RECEIVEDDATA_ACTION);
        registerReceiver(receiver, intentFilter);
    }

    @Override
    protected void onPause() {
        unregisterReceiver(receiver);
        super.onPause();
    }

    @Override
    protected void onDestroy() {
        stopScannerService();
        String model = SharedPreferencesUtil.getString("model", "");
        if (model.contains("Q") || model.contains("q")) {
            keySwitchToTiggerQcom("1"); //高通平台需要写入节点下电
        }
        super.onDestroy();
    }

    void startScannerService() {
        Intent intent = new Intent(MainActivity.this, ScannerService.class);
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            startForegroundService(intent);
        } else {
            startService(intent);
        }
    }
    void stopScannerService() {
        stopService(new Intent(MainActivity.this, ScannerService.class));
    }

    // 写入节点数据控制上下电(高通平台)
    private void keySwitchToTiggerQcom(String value){
        byte[] trigger = value.getBytes();
        try {
            File file = new File("/sys/class/EMDEBUG/gpio_ctrl");
            FileOutputStream fos = new FileOutputStream(file);
            fos.write(trigger);
            fos.flush();
            fos.close();
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}
