package com.emdoor.scannerdemo;

import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.Service;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.AsyncTask;
import android.os.IBinder;
import android.os.RemoteException;
import android.os.ServiceManager;
import android.view.IWindowManager;

import com.emdoor.scannerdemo.utils.FileNodeUtil;
import com.emdoor.scannerdemo.utils.SharedPreferencesUtil;
import com.zebra.BarcodeScanner;
import com.zebra.ScannerParams;

public class ScannerService extends Service {
    // 接收SCAN_R键广播
    static public final String ACTION_KEYEVENT_KEYCODE_SCAN_R_DOWN = "com.android.action.keyevent.KEYCODE_KEYCODE_SCAN_R_DOWN";
    static public final String ACTION_KEYEVENT_KEYCODE_SCAN_R_UP = "com.android.action.keyevent.KEYCODE_KEYCODE_SCAN_R_UP";
    // 接收SCAN_L键广播
    static public final String ACTION_KEYEVENT_KEYCODE_SCAN_L_DOWN = "com.android.action.keyevent.KEYCODE_KEYCODE_SCAN_L_DOWN";
    static public final String ACTION_KEYEVENT_KEYCODE_SCAN_L_UP = "com.android.action.keyevent.KEYCODE_KEYCODE_SCAN_L_UP";
    // 接收SCAN_F键广播
    public static final String ACTION_KEYEVENT_SCANCENTER_DOWN = "com.android.action.keyevent.KEYCODE_KEYCODE_SCAN_F_DOWN";
    public static final String ACTION_KEYEVENT_SCANCENTER_UP = "com.android.action.keyevent.KEYCODE_KEYCODE_SCAN_F_UP";
    // 接收蓝牙手柄广播
    public static final String ACTION_BLUETOOTH_SCANNER = "com_android_action_bluetooth_scanner";
    public static final String ACTION_BLUETOOTH_SCANNER_CANCEL = "com_android_action_bluetooth_scanner_up";

    public static final String id = "scannerdemo_service";
    public static final String name = "scannerdemo_service";

    private ScannerParams mParams;
    private IWindowManager iWindowManager;

    private BroadcastReceiver receiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            if (action != null) {
                switch (action) {
                    case BarcodeScanner.BARCODEPORT_RECEIVEDDATA_ACTION:
                        // 接收扫码数据
                        // 后台运行时把数据写入到焦点
                        String data = intent.getStringExtra(BarcodeScanner.BARCODEPORT_RECEIVEDDATA_EXTRA_DATA);
                        if (SharedPreferencesUtil.getBoolean("widgetMode", false)) {
                            try {
                                iWindowManager.sendScanDataToFocus(data, 0, 0);                     // WIDGET 控件模式
                            } catch (RemoteException e) {
                                e.printStackTrace();
                            }
                        } else {
                            synchronized (this) {
                                WriteDataAsyncTask writeDataAsyncTask = new WriteDataAsyncTask();   // HID 模式
                                writeDataAsyncTask.execute(data);
                            }
                        }
                        break;
                    case ACTION_KEYEVENT_KEYCODE_SCAN_R_DOWN:
                    case ACTION_KEYEVENT_KEYCODE_SCAN_L_DOWN:
                    case ACTION_KEYEVENT_SCANCENTER_DOWN:
                    case ACTION_BLUETOOTH_SCANNER:
                        // 按键按下时扫码
                        BarcodeScanner.decode();
                        break;
                    case ACTION_KEYEVENT_KEYCODE_SCAN_R_UP:
                    case ACTION_KEYEVENT_KEYCODE_SCAN_L_UP:
                    case ACTION_KEYEVENT_SCANCENTER_UP:
                    case ACTION_BLUETOOTH_SCANNER_CANCEL:
                        // 按键弹起时停止扫码
                        if (BarcodeScanner.hasBarcodeReader()) {
                            BarcodeScanner.stopDecode();
                        } else {
                            BarcodeScanner.init(mParams);
                        }
                        break;
                    case Intent.ACTION_SCREEN_ON:
                        BarcodeScanner.init(mParams);
                        break;
                    case Intent.ACTION_SCREEN_OFF:
                        BarcodeScanner.release();
                        break;
                    default:
                        break;
                }
            }
        }
    };

    public ScannerService() {
    }

    @Override
    public IBinder onBind(Intent intent) {
        // TODO: Return the communication channel to the service.
        throw new UnsupportedOperationException("Not yet implemented");
    }

    @Override
    public void onCreate() {
        super.onCreate();
        //适配8.0service
        NotificationManager notificationManager = (NotificationManager) this.getSystemService(Context.NOTIFICATION_SERVICE);
        NotificationChannel mChannel = null;
        if (android.os.Build.VERSION.SDK_INT >= android.os.Build.VERSION_CODES.O) {
            mChannel = new NotificationChannel(id, name, NotificationManager.IMPORTANCE_NONE);
            notificationManager.createNotificationChannel(mChannel);
            Notification notification = new Notification.Builder(getApplicationContext(), id).build();
            startForeground(1, notification);
        }

        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction(BarcodeScanner.BARCODEPORT_RECEIVEDDATA_ACTION);
        intentFilter.addAction(ACTION_KEYEVENT_KEYCODE_SCAN_R_DOWN);
        intentFilter.addAction(ACTION_KEYEVENT_KEYCODE_SCAN_R_UP);
        intentFilter.addAction(ACTION_KEYEVENT_KEYCODE_SCAN_L_DOWN);
        intentFilter.addAction(ACTION_KEYEVENT_KEYCODE_SCAN_L_UP);
        intentFilter.addAction(ACTION_KEYEVENT_SCANCENTER_UP);
        intentFilter.addAction(ACTION_KEYEVENT_SCANCENTER_DOWN);
        intentFilter.addAction(ACTION_BLUETOOTH_SCANNER);
        intentFilter.addAction(ACTION_BLUETOOTH_SCANNER_CANCEL);
        intentFilter.addAction(Intent.ACTION_SCREEN_ON);
        intentFilter.addAction(Intent.ACTION_SCREEN_OFF);
        registerReceiver(receiver, intentFilter);

        BarcodeScanner.prepare(this);       // 在其他方法之前调用prepare方法
        mParams = new ScannerParams();
        mParams.readerId = SharedPreferencesUtil.getInt("readerId", 1); // readerId 基于摄像头数量
        // List<BarcodeBean> beans = BarcodeScanner.getPresetBarcodeArray();   // 可选项，如果不需要自行配置码制则
        // BarcodeScanner.setBarcodeBeans(beans);                              // 不需要这么做
        BarcodeScanner.init(mParams);       // 初始化Scanner

        iWindowManager = IWindowManager.Stub.asInterface(ServiceManager.getService(Context.WINDOW_SERVICE));
    }

    @Override
    public void onDestroy() {
        unregisterReceiver(receiver);
        BarcodeScanner.release();
        super.onDestroy();
    }

    /**
     * /sys/class/EM_BT_CONTROL/input_buf
     * */
    private String inputPath="/sys/class/EM_BT_CONTROL/input_buf";
    private String inputPathEnter="/sys/class/EM_BT_CONTROL/input_buf_enter";
    private boolean hasEnter = false;
    /**
     * 把数据写入到节点
     * */
    private class WriteDataAsyncTask extends AsyncTask<String, Integer, Integer> {
        @Override
        protected Integer doInBackground(String... params) {
            int res=0;
            String data = params != null && params.length > 0 ? params[0] : null;
            if (data != null) {
                if(hasEnter){
                    FileNodeUtil.write(inputPathEnter, data);
                }else{
                    FileNodeUtil.write(inputPath, data);
                }
            }
            return res;
        }
    }
}
