package com.emdoor.scannerdemo.utils;

import android.util.Xml;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

public class XmlConfigUtil {
    private static final String configPath = "vendor/etc/scanner_config.xml";
    /**
     * 解析存在设备的xml获取配置信息
     * @return
     */
    public static XmlConfig getXmlConfig(){
        XmlConfig ret = new XmlConfig();
        XmlBroadcastConfig broadcastConfig = null;
        List<XmlBroadcastConfig> list = new ArrayList<>();
        try {
            File file = new File(configPath);
            FileInputStream inputStream = new FileInputStream(file);
            XmlPullParser xml = Xml.newPullParser();
            xml.setInput(inputStream, "UTF-8");
            int eventType = xml.getEventType();
            while (eventType != XmlPullParser.END_DOCUMENT){
                String name = xml.getName();
                switch (eventType){
                    case XmlPullParser.START_DOCUMENT:
                        break;
                    case XmlPullParser.START_TAG:
                        if("property".equalsIgnoreCase(name)){
                            String nameSetting = xml.getAttributeValue(0);
                            String value = xml.getAttributeValue(1);
                            switch (nameSetting){
                                case "model":
                                    ret.model = value;
                                    break;
                                case "openService_reboot":
                                    ret.openService_reboot = Boolean.parseBoolean(value);
                                    break;
                                case "SerialPortName":
                                    ret.SerialPortName = value;
                                    break;
                                case "FileNodePowerOn":
                                    ret.FileNodePowerOn = value;
                                    break;
                                case "scanVoice":
                                    ret.scanVoice = Boolean.parseBoolean(value);
                                    break;
                                case "scanVibrate":
                                    ret.scanVibrate = Boolean.parseBoolean(value);
                                    break;
                                case "HIDChoose":
                                    ret.HIDChoose = Boolean.parseBoolean(value);
                                    break;
                                case "EnterChoose":
                                    ret.EnterChoose = Boolean.parseBoolean(value);
                                    break;
                                case "TabChoose":
                                    ret.TabChoose = value;
                                    break;
                                case "ScanModel":
                                    ret.ScanModel = value;
                                    break;
                                case "FileNodeCloseOpen":
                                    ret.FileNodeCloseOpen = value;
                                    break;
                                case "ScreenDirection":
                                    ret.ScreenDirection = value;
                                    break;
                                case "ClipBoardChoose":
                                    ret.ClipBoardChoose = Boolean.parseBoolean(value);
                                    break;
                                case "ReaderID":
                                    ret.ReaderID = Integer.parseInt(value);
                                    break;
                                case "WidgetChoose":
                                    ret.WidgetChoose = Boolean.parseBoolean(value);
                                    break;
                                default:
                                    break;
                            }

                        }
                        if ("button".equalsIgnoreCase(name)) {
                            broadcastConfig = new XmlBroadcastConfig();
                            String id = xml.getAttributeValue(0);
                            broadcastConfig.id = id;

                        } else if(broadcastConfig != null) {
                            if ("closeBroadcast".equalsIgnoreCase(name)) {
                                String s = xml.nextText();
                                broadcastConfig.closeBroadcast = s;
                            }
                            if ("value".equalsIgnoreCase(name)) {
                                String value = xml.nextText();
                                broadcastConfig.value = value;
                            }
                            if ("openBroadcast".equalsIgnoreCase(name)) {
                                broadcastConfig.openBroadcast = xml.nextText();
                            }
                        }
                        break;
                    case XmlPullParser.END_TAG:
                        if ("button".equals(name) && broadcastConfig !=null) {
                            list.add(broadcastConfig);
                            broadcastConfig = null;
                        }
                        if(name.equalsIgnoreCase("deviceCofing")){
                            ret.broadcasts = list;
                        }

                        break;
                }
                eventType = xml.next();
            }
        } catch (XmlPullParserException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
        return ret;
    }

    public static class XmlConfig {
        public String model;
        public boolean openService_reboot;
        public boolean scanVoice;
        public String SerialPortName;
        public String FileNodePowerOn;
        public boolean scanVibrate;
        public boolean HIDChoose;
        public boolean EnterChoose;
        public String TabChoose;
        public String ScanModel;
        public String ScreenDirection;
        public String FileNodeCloseOpen;
        public boolean ClipBoardChoose;
        public int ReaderID = 1;
        public boolean SerialPortSwitch;
        public String FileNodeChannelSwitch;
        public int FileNodeChannelValue;
        public boolean WidgetChoose;
        public List<XmlBroadcastConfig> broadcasts;
    }

    public static class XmlBroadcastConfig {
        public String id;
        public String closeBroadcast;
        public String openBroadcast;
        public String value;
    }
}
